Skip to contents

Estimates the average number of months required for a publication to receive one citation.

Usage

citation_speed(data, n = 10)

Arguments

data

A tidy data frame created by clean_scopus().

n

Number of rows to return (default = 10).

Value

A tidy data frame containing publication year, journal name, and estimated months per citation.

Author

Jose V. Die