Skip to contents

Fits a linear regression model describing the relationship between h-index and year.

Usage

fit_h_model(data, start_year = NULL, end_year = NULL, h = 0)

Arguments

data

A tidy data frame created by clean_scopus().

start_year

Optional starting year for the analysis.

end_year

Optional ending year for the analysis.

h

Initial h-index value (default = 0).

Value

An object of class lm.

Details

The fitted model assumes linear growth of the h-index over time.

Author

Jose V. Die