Skip to contents

Plots the observed h-index trajectory together with a fitted linear regression model.

Usage

plot_h_model(data, start_year = NULL, end_year = NULL, h = 0)

Arguments

data

A tidy data frame created by clean_scopus().

start_year

Optional starting year for the analysis.

end_year

Optional ending year for the analysis.

h

Initial h-index value (default = 0).

Value

A ggplot object containing observed values and fitted trend.

Author

Jose V. Die