Skip to contents

Estimates the expected number of citations over a specified time window based on historical citation speed.

Usage

predict_citations(data, term = 12)

Arguments

data

A tidy data frame created by clean_scopus().

term

Numeric value indicating the prediction period in months.

Value

A tidy data frame containing estimated future citations.

Details

Citation projections are based on a simple linear approximation:

$$ expected\_citations = \left\lfloor \frac{term}{months\_per\_citation} \right\rfloor $$

See also

citation_speed

Author

Jose V. Die